@@ -78,7 +78,7 @@ public static class FAudio
 	public const uint FAUDIO_TARGET_VERSION = 8;
 
 	public const uint FAUDIO_ABI_VERSION =		 0;
-	public const uint FAUDIO_MAJOR_VERSION =	21;
+	public const uint FAUDIO_MAJOR_VERSION =	22;
 	public const uint FAUDIO_MINOR_VERSION =	 2;
 	public const uint FAUDIO_PATCH_VERSION =	 0;
 
@@ -176,6 +176,22 @@ public static class FAudio
 		 */
 	}
 
+	public struct FAudioXMA2WaveFormatEx
+	{
+		public FAudioWaveFormatEx wfx;
+		public ushort wNumStreams;
+		public uint dwChannelMask;
+		public uint dwSamplesEncoded;
+		public uint dwBytesPerBlock;
+		public uint dwPlayBegin;
+		public uint dwPlayLength;
+		public uint dwLoopBegin;
+		public uint dwLoopLength;
+		public byte bLoopCount;
+		public byte bEncoderVersion;
+		public ushort wBlockCount;
+	};
+
 	[StructLayout(LayoutKind.Sequential, Pack = 1)]
 	public unsafe struct FAudioDeviceDetails
 	{
@@ -405,6 +421,18 @@ public static class FAudio
 		IntPtr pEffectChain /* FAudioEffectChain* */
 	);
 
+	[DllImport(nativeLibName, CallingConvention = CallingConvention.Cdecl)]
+	public static extern uint FAudio_CreateSourceVoice(
+		IntPtr audio, /* FAudio* */
+		out IntPtr ppSourceVoice, /* FAudioSourceVoice** */
+		IntPtr pSourceFormat, /* FAudioWaveFormatEx* */
+		uint Flags,
+		float MaxFrequencyRatio,
+		IntPtr pCallback, /* FAudioVoiceCallback* */
+		IntPtr pSendList, /* FAudioVoiceSends* */
+		IntPtr pEffectChain /* FAudioEffectChain* */
+	);
+
 	[DllImport(nativeLibName, CallingConvention = CallingConvention.Cdecl)]
 	public static extern uint FAudio_CreateSubmixVoice(
 		IntPtr audio, /* FAudio* */
@@ -625,6 +653,13 @@ public static class FAudio
 		IntPtr pBufferWMA /* const FAudioBufferWMA* */
 	);
 
+	[DllImport(nativeLibName, CallingConvention = CallingConvention.Cdecl)]
+	public static extern uint FAudioSourceVoice_SubmitSourceBuffer(
+		IntPtr voice, /* FAudioSourceVoice* */
+		ref FAudioBuffer pBuffer,
+		ref FAudioBufferWMA pBufferWMA
+	);
+
 	[DllImport(nativeLibName, CallingConvention = CallingConvention.Cdecl)]
 	public static extern uint FAudioSourceVoice_FlushSourceBuffers(
 		IntPtr voice /* FAudioSourceVoice* */
@@ -2333,6 +2368,14 @@ public static class FAudio
 		int num_floats
 	);
 
+	[DllImport(nativeLibName, CallingConvention = CallingConvention.Cdecl)]
+	public static extern int stb_vorbis_get_samples_float_interleaved(
+		IntPtr f,
+		int channels,
+		IntPtr buffer,
+		int num_floats
+	);
+
 	[DllImport(nativeLibName, CallingConvention = CallingConvention.Cdecl)]
 	public static extern int stb_vorbis_get_samples_float(
 		IntPtr f,
