@@ -1,6 +1,6 @@
 /* FAudio - XAudio Reimplementation for FNA
  *
- * Copyright (c) 2011-2020 Ethan Lee, Luigi Auriemma, and the MonoGame Team
+ * Copyright (c) 2011-2021 Ethan Lee, Luigi Auriemma, and the MonoGame Team
  *
  * This software is provided 'as-is', without any express or implied warranty.
  * In no event will the authors be held liable for any damages arising from
@@ -312,6 +312,25 @@ typedef struct FAudioDebugConfiguration
 
 #pragma pack(pop)
 
+/* This ISN'T packed. Strictly speaking it wouldn't have mattered anyway but eh.
+ * See https://github.com/microsoft/DirectXTK/issues/256
+ */
+typedef struct FAudioXMA2WaveFormatEx
+{
+	FAudioWaveFormatEx wfx;
+	uint16_t wNumStreams;
+	uint32_t dwChannelMask;
+	uint32_t dwSamplesEncoded;
+	uint32_t dwBytesPerBlock;
+	uint32_t dwPlayBegin;
+	uint32_t dwPlayLength;
+	uint32_t dwLoopBegin;
+	uint32_t dwLoopLength;
+	uint8_t  bLoopCount;
+	uint8_t  bEncoderVersion;
+	uint16_t wBlockCount;
+} FAudioXMA2WaveFormat;
+
 /* Constants */
 
 #define FAUDIO_E_OUT_OF_MEMORY		0x8007000e
@@ -390,7 +409,7 @@ typedef struct FAudioDebugConfiguration
 #define _SPEAKER_POSITIONS_
 #endif
 
-#ifndef _SPEAKER_COMBINATIONS_
+#ifndef SPEAKER_MONO
 #define SPEAKER_MONO	SPEAKER_FRONT_CENTER
 #define SPEAKER_STEREO	(SPEAKER_FRONT_LEFT | SPEAKER_FRONT_RIGHT)
 #define SPEAKER_2POINT1 \
@@ -446,7 +465,6 @@ typedef struct FAudioDebugConfiguration
 		SPEAKER_SIDE_LEFT	| \
 		SPEAKER_SIDE_RIGHT	)
 #define SPEAKER_XBOX SPEAKER_5POINT1
-#define _SPEAKER_COMBINATIONS_
 #endif
 
 #define FAUDIO_FORMAT_PCM		1
@@ -466,8 +484,8 @@ extern FAudioGUID DATAFORMAT_SUBTYPE_IEEE_FLOAT;
 #define FAUDIO_TARGET_VERSION 8 /* Targeting compatibility with XAudio 2.8 */
 
 #define FAUDIO_ABI_VERSION	 0
-#define FAUDIO_MAJOR_VERSION	20
-#define FAUDIO_MINOR_VERSION	 4
+#define FAUDIO_MAJOR_VERSION	22
+#define FAUDIO_MINOR_VERSION	 2
 #define FAUDIO_PATCH_VERSION	 0
 
 #define FAUDIO_COMPILED_VERSION ( \
