@@ -89,7 +89,7 @@ typedef struct FACTDSPParameter
 typedef struct FACTDSPPreset
 {
 	uint8_t accessibility;
-	uint32_t parameterCount;
+	uint16_t parameterCount;
 	FACTDSPParameter *parameters;
 } FACTDSPPreset;
 
@@ -440,6 +440,9 @@ struct FACTAudioEngine
 	void *sb_context;
 	void *wb_context;
 	void *wave_context;
+
+	/* Settings handle */
+	void *settings;
 };
 
 struct FACTSoundBank
@@ -487,6 +490,7 @@ struct FACTWaveBank
 	FACTWaveBankEntry *entries;
 	uint32_t *entryRefs;
 	FACTSeekTable *seekTables;
+	char *waveBankNames;
 
 	/* I/O information */
 	uint32_t packetSize;
@@ -582,6 +586,8 @@ void FACT_INTERNAL_DestroySound(FACTSoundInstance *sound);
 void FACT_INTERNAL_BeginFadeOut(FACTSoundInstance *sound, uint16_t fadeOutMS);
 void FACT_INTERNAL_BeginReleaseRPC(FACTSoundInstance *sound, uint16_t releaseMS);
 
+void FACT_INTERNAL_SendCueNotification(FACTCue *cue, FACTNoticationsFlags flag, uint8_t type);
+
 /* RPC Helper Functions */
 
 FACTRPC* FACT_INTERNAL_GetRPC(FACTAudioEngine *engine, uint32_t code);
