@@ -293,7 +293,6 @@ uint32_t FAudio_CreateSourceVoice(
 
 	if (	pSourceFormat->wFormatTag == FAUDIO_FORMAT_PCM ||
 		pSourceFormat->wFormatTag == FAUDIO_FORMAT_IEEE_FLOAT ||
-		pSourceFormat->wFormatTag == FAUDIO_FORMAT_XMAUDIO2 ||
 		pSourceFormat->wFormatTag == FAUDIO_FORMAT_WMAUDIO2	)
 	{
 		FAudioWaveFormatExtensible *fmtex = (FAudioWaveFormatExtensible*) audio->pMalloc(
@@ -317,10 +316,6 @@ uint32_t FAudio_CreateSourceVoice(
 		{
 			FAudio_memcpy(&fmtex->SubFormat, &DATAFORMAT_SUBTYPE_IEEE_FLOAT, sizeof(FAudioGUID));
 		}
-		else if (pSourceFormat->wFormatTag == FAUDIO_FORMAT_XMAUDIO2)
-		{
-			FAudio_memcpy(&fmtex->SubFormat, &DATAFORMAT_SUBTYPE_XMAUDIO2, sizeof(FAudioGUID));
-		}
 		else if (pSourceFormat->wFormatTag == FAUDIO_FORMAT_WMAUDIO2)
 		{
 			FAudio_memcpy(&fmtex->SubFormat, &DATAFORMAT_SUBTYPE_WMAUDIO2, sizeof(FAudioGUID));
@@ -355,6 +350,31 @@ uint32_t FAudio_CreateSourceVoice(
 		) - 6) * 2;
 		(*ppSourceVoice)->src.format = &fmtex->wfx;
 	}
+	else if (pSourceFormat->wFormatTag == FAUDIO_FORMAT_XMAUDIO2)
+	{
+		FAudioXMA2WaveFormat *fmtex = (FAudioXMA2WaveFormat*) audio->pMalloc(
+			sizeof(FAudioXMA2WaveFormat)
+		);
+
+		/* Copy what we can, ideally the sizes match! */
+		size_t cbSize = sizeof(FAudioWaveFormatEx) + pSourceFormat->cbSize;
+		FAudio_memcpy(
+			fmtex,
+			pSourceFormat,
+			FAudio_min(cbSize, sizeof(FAudioXMA2WaveFormat))
+		);
+		if (cbSize < sizeof(FAudioXMA2WaveFormat))
+		{
+			FAudio_zero(
+				((uint8_t*) fmtex) + cbSize,
+				sizeof(FAudioADPCMWaveFormat) - cbSize
+			);
+		}
+
+		/* Does XAudio2 validate this input?! */
+		fmtex->wfx.cbSize = sizeof(FAudioXMA2WaveFormat) - sizeof(FAudioWaveFormatEx);
+		(*ppSourceVoice)->src.format = &fmtex->wfx;
+	}
 	else
 	{
 		/* direct copy anything else */
@@ -429,18 +449,17 @@ uint32_t FAudio_CreateSourceVoice(
 		}
 		else if (	COMPARE_GUID(WMAUDIO2) ||
 				COMPARE_GUID(WMAUDIO3) ||
-				COMPARE_GUID(WMAUDIO_LOSSLESS) ||
-				COMPARE_GUID(XMAUDIO2)	)
+				COMPARE_GUID(WMAUDIO_LOSSLESS)	)
 		{
-#ifdef HAVE_GSTREAMER
-			if (FAudio_GSTREAMER_init(*ppSourceVoice, fmtex->SubFormat.Data1) != 0)
+#ifdef HAVE_WMADEC
+			if (FAudio_WMADEC_init(*ppSourceVoice, fmtex->SubFormat.Data1) != 0)
 			{
 				(*ppSourceVoice)->src.decode = FAudio_INTERNAL_DecodeWMAERROR;
 			}
 #else
 			FAudio_assert(0 && "xWMA is not supported!");
 			(*ppSourceVoice)->src.decode = FAudio_INTERNAL_DecodeWMAERROR;
-#endif /* HAVE_GSTREAMER */
+#endif /* HAVE_WMADEC */
 		}
 		else
 		{
@@ -448,6 +467,18 @@ uint32_t FAudio_CreateSourceVoice(
 		}
 		#undef COMPARE_GUID
 	}
+	else if ((*ppSourceVoice)->src.format->wFormatTag == FAUDIO_FORMAT_XMAUDIO2)
+	{
+#ifdef HAVE_WMADEC
+		if (FAudio_WMADEC_init(*ppSourceVoice, FAUDIO_FORMAT_XMAUDIO2) != 0)
+		{
+			(*ppSourceVoice)->src.decode = FAudio_INTERNAL_DecodeWMAERROR;
+		}
+#else
+		FAudio_assert(0 && "XMA2 is not supported!");
+		(*ppSourceVoice)->src.decode = FAudio_INTERNAL_DecodeWMAERROR;
+#endif /* HAVE_WMADEC */
+	}
 	else if ((*ppSourceVoice)->src.format->wFormatTag == FAUDIO_FORMAT_MSADPCM)
 	{
 		(*ppSourceVoice)->src.decode = ((*ppSourceVoice)->src.format->nChannels == 2) ?
@@ -2208,12 +2239,12 @@ void FAudioVoice_DestroyVoice(FAudioVoice *voice)
 		voice->audio->pFree(voice->src.format);
 		LOG_MUTEX_DESTROY(voice->audio, voice->src.bufferLock)
 		FAudio_PlatformDestroyMutex(voice->src.bufferLock);
-#ifdef HAVE_GSTREAMER
-		if (voice->src.gstreamer)
+#ifdef HAVE_WMADEC
+		if (voice->src.wmadec)
 		{
-			FAudio_GSTREAMER_free(voice);
+			FAudio_WMADEC_free(voice);
 		}
-#endif /* HAVE_GSTREAMER */
+#endif /* HAVE_WMADEC */
 	}
 	else if (voice->type == FAUDIO_VOICE_SUBMIX)
 	{
@@ -2421,10 +2452,12 @@ uint32_t FAudioSourceVoice_SubmitSourceBuffer(
 	)
 
 	FAudio_assert(voice->type == FAUDIO_VOICE_SOURCE);
-#ifdef HAVE_GSTREAMER
-	FAudio_assert(	(voice->src.gstreamer != NULL && pBufferWMA != NULL) ||
-			(voice->src.gstreamer == NULL && pBufferWMA == NULL)	);
-#endif /* HAVE_GSTREAMER */
+#ifdef HAVE_WMADEC
+	FAudio_assert(	(voice->src.wmadec != NULL && (pBufferWMA != NULL ||
+					(voice->src.format->wFormatTag == FAUDIO_FORMAT_XMAUDIO2 ||
+					 voice->src.format->wFormatTag == FAUDIO_FORMAT_EXTENSIBLE))) ||
+			(voice->src.wmadec == NULL && (pBufferWMA == NULL && voice->src.format->wFormatTag != FAUDIO_FORMAT_XMAUDIO2))	);
+#endif /* HAVE_WMADEC */
 
 	/* Start off with whatever they just sent us... */
 	playBegin = pBuffer->PlayBegin;
@@ -2451,6 +2484,11 @@ uint32_t FAudioSourceVoice_SubmitSourceBuffer(
 				fmtex->wSamplesPerBlock
 			) - playBegin;
 		}
+		else if (voice->src.format->wFormatTag == FAUDIO_FORMAT_XMAUDIO2)
+		{
+			FAudioXMA2WaveFormat *fmtex = (FAudioXMA2WaveFormat*) voice->src.format;
+			playLength = fmtex->dwSamplesEncoded - playBegin;
+		}
 		else if (pBufferWMA != NULL)
 		{
 			playLength = (
@@ -2467,7 +2505,7 @@ uint32_t FAudioSourceVoice_SubmitSourceBuffer(
 		}
 	}
 
-	if (pBuffer->LoopCount > 0 && pBufferWMA == NULL)
+	if (pBuffer->LoopCount > 0 && pBufferWMA == NULL && voice->src.format->wFormatTag != FAUDIO_FORMAT_XMAUDIO2)
 	{
 		/* "The value of LoopBegin must be less than PlayBegin + PlayLength" */
 		if (loopBegin >= (playBegin + playLength))
@@ -2509,7 +2547,7 @@ uint32_t FAudioSourceVoice_SubmitSourceBuffer(
 			pBuffer->AudioBytes / voice->src.format->nBlockAlign
 		) * voice->src.format->nBlockAlign;
 	}
-	else if (pBufferWMA != NULL)
+	else if (pBufferWMA != NULL || voice->src.format->wFormatTag == FAUDIO_FORMAT_XMAUDIO2)
 	{
 		/* WMA only supports looping the whole buffer */
 		loopBegin = 0;
