@@ -305,14 +305,14 @@ static uint32_t FAudio_INTERNAL_GetBytesRequested(
 
 	LOG_FUNC_ENTER(voice->audio)
 
-#ifdef HAVE_GSTREAMER
-	if (voice->src.gstreamer != NULL)
+#ifdef HAVE_WMADEC
+	if (voice->src.wmadec != NULL)
 	{
 		/* Always 0, per the spec */
 		LOG_FUNC_EXIT(voice->audio)
 		return 0;
 	}
-#endif /* HAVE_GSTREAMER */
+#endif /* HAVE_WMADEC */
 	while (list != NULL && decoding > 0)
 	{
 		buffer = &list->buffer;
@@ -455,12 +455,12 @@ static void FAudio_INTERNAL_DecodeBuffers(
 			}
 			else
 			{
-#ifdef HAVE_GSTREAMER
-				if (voice->src.gstreamer != NULL)
+#ifdef HAVE_WMADEC
+				if (voice->src.wmadec != NULL)
 				{
-					FAudio_GSTREAMER_end_buffer(voice);
+					FAudio_WMADEC_end_buffer(voice);
 				}
-#endif /* HAVE_GSTREAMER */
+#endif /* HAVE_WMADEC */
 				/* For EOS we can stop storing fraction offsets */
 				if (buffer->Flags & FAUDIO_END_OF_STREAM)
 				{
@@ -999,15 +999,6 @@ static void FAudio_INTERNAL_MixSource(FAudioSourceVoice *voice)
 
 sendwork:
 
-	/* Nowhere to send it? Just skip the rest...*/
-	if (voice->sends.SendCount == 0)
-	{
-		FAudio_PlatformUnlockMutex(voice->sendLock);
-		LOG_MUTEX_UNLOCK(voice->audio, voice->sendLock)
-		LOG_FUNC_EXIT(voice->audio)
-		return;
-	}
-
 	/* Filters */
 	if (voice->flags & FAUDIO_VOICE_USEFILTER)
 	{
@@ -1050,6 +1041,15 @@ sendwork:
 	FAudio_PlatformUnlockMutex(voice->effectLock);
 	LOG_MUTEX_UNLOCK(voice->audio, voice->effectLock)
 
+	/* Nowhere to send it? Just skip the rest...*/
+	if (voice->sends.SendCount == 0)
+	{
+		FAudio_PlatformUnlockMutex(voice->sendLock);
+		LOG_MUTEX_UNLOCK(voice->audio, voice->sendLock)
+		LOG_FUNC_EXIT(voice->audio)
+		return;
+	}
+
 	/* Send float cache to sends */
 	FAudio_PlatformLockMutex(voice->volumeLock);
 	LOG_MUTEX_LOCK(voice->audio, voice->volumeLock)
@@ -1110,12 +1110,6 @@ static void FAudio_INTERNAL_MixSubmix(FAudioSubmixVoice *voice)
 	FAudio_PlatformLockMutex(voice->sendLock);
 	LOG_MUTEX_LOCK(voice->audio, voice->sendLock)
 
-	/* Nothing to do? */
-	if (voice->sends.SendCount == 0)
-	{
-		goto end;
-	}
-
 	/* Resample */
 	if (voice->mix.resampleStep == FIXED_ONE)
 	{
@@ -1182,6 +1176,12 @@ static void FAudio_INTERNAL_MixSubmix(FAudioSubmixVoice *voice)
 	FAudio_PlatformUnlockMutex(voice->effectLock);
 	LOG_MUTEX_UNLOCK(voice->audio, voice->effectLock)
 
+	/* Nothing more to do? */
+	if (voice->sends.SendCount == 0)
+	{
+		goto end;
+	}
+
 	/* Send float cache to sends */
 	FAudio_PlatformLockMutex(voice->volumeLock);
 	LOG_MUTEX_LOCK(voice->audio, voice->volumeLock)
