@@ -28,19 +28,23 @@
 #include "FAPOBase.h"
 #include <stdarg.h>
 
-#ifdef FAUDIO_UNKNOWN_PLATFORM
+#ifdef FAUDIO_WIN32_PLATFORM
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <malloc.h>
 #include <math.h>
 #include <assert.h>
 #include <inttypes.h>
 
+#include <windef.h>
+#include <winbase.h>
+
 #define FAudio_malloc malloc
 #define FAudio_realloc realloc
 #define FAudio_free free
-#define FAudio_alloca(x) alloca(uint8_t, x)
-#define FAudio_dealloca(x) dealloca(x)
+#define FAudio_alloca(x) alloca(x)
+#define FAudio_dealloca(x) (void)(x)
 #define FAudio_zero(ptr, size) memset(ptr, '\0', size)
 #define FAudio_memset(ptr, val, size) memset(ptr, val, size)
 #define FAudio_memcpy(dst, src, size) memcpy(dst, src, size)
@@ -49,7 +53,8 @@
 
 #define FAudio_strlen(ptr) strlen(ptr)
 #define FAudio_strcmp(str1, str2) strcmp(str1, str2)
-#define FAudio_strlcpy(ptr1, ptr2, size) strlcpy(ptr1, ptr2, size)
+#define FAudio_strncmp(str1, str2, size) strncmp(str1, str2, size)
+#define FAudio_strlcpy(ptr1, ptr2, size) lstrcpynA(ptr1, ptr2, size)
 
 #define FAudio_pow(x, y) pow(x, y)
 #define FAudio_log(x) log(x)
@@ -76,11 +81,12 @@
 #define FAudio_assert assert
 #define FAudio_snprintf snprintf
 #define FAudio_vsnprintf vsnprintf
-#define FAudio_Log(msg) fprintf(stderr, "%s\n", msg)
 #define FAudio_getenv getenv
 #define FAudio_PRIu64 PRIu64
 #define FAudio_PRIx64 PRIx64
 
+extern void FAudio_Log(char const *msg);
+
 /* FIXME: Assuming little-endian! */
 #define FAudio_swap16LE(x) (x)
 #define FAudio_swap16BE(x) \
@@ -121,6 +127,7 @@
 
 #define FAudio_strlen(ptr) SDL_strlen(ptr)
 #define FAudio_strcmp(str1, str2) SDL_strcmp(str1, str2)
+#define FAudio_strncmp(str1, str2, size) SDL_strncmp(str1, str1, size)
 #define FAudio_strlcpy(ptr1, ptr2, size) SDL_strlcpy(ptr1, ptr2, size)
 
 #define FAudio_pow(x, y) SDL_pow(x, y)
@@ -464,10 +471,10 @@ struct FAudioVoice
 			uint64_t curBufferOffsetDec;
 			uint32_t curBufferOffset;
 
-			/* GStreamer */
-#ifdef HAVE_GSTREAMER
-			struct FAudioGSTREAMER *gstreamer;
-#endif /* HAVE_GSTREAMER*/
+			/* WMA decoding */
+#ifdef HAVE_WMADEC
+			struct FAudioWMADEC *wmadec;
+#endif /* HAVE_WMADEC*/
 
 			/* Read-only */
 			float maxFreqRatio;
@@ -732,13 +739,13 @@ DECODE_FUNC(StereoMSADPCM)
 DECODE_FUNC(WMAERROR)
 #undef DECODE_FUNC
 
-/* GStreamer */
+/* WMA decoding */
 
-#ifdef HAVE_GSTREAMER
-uint32_t FAudio_GSTREAMER_init(FAudioSourceVoice *pSourceVoice, uint32_t type);
-void FAudio_GSTREAMER_free(FAudioSourceVoice *voice);
-void FAudio_GSTREAMER_end_buffer(FAudioSourceVoice *voice);
-#endif /* HAVE_GSTREAMER */
+#ifdef HAVE_WMADEC
+uint32_t FAudio_WMADEC_init(FAudioSourceVoice *pSourceVoice, uint32_t type);
+void FAudio_WMADEC_free(FAudioSourceVoice *voice);
+void FAudio_WMADEC_end_buffer(FAudioSourceVoice *voice);
+#endif /* HAVE_WMADEC */
 
 /* Platform Functions */
 
